@@ -477,7 +477,8 @@ ccss_property (CRDocHandler *a_handler, GString *a_name,
 			   CRTerm *a_expr, gboolean a_important)
 {
 	CSSUserData * user_data;
-	char * expr = NULL;
+	char * expr = NULL, *name = NULL;
+	size_t len;
 
 	g_return_if_fail (a_handler);
 
@@ -485,7 +486,10 @@ ccss_property (CRDocHandler *a_handler, GString *a_name,
 
 	if (a_name && a_name->str && a_expr && user_data->def)
 		{
-			g_string_append_len (user_data->def, a_name->str, a_name->len);
+			name = a_name->str;
+			len = a_name->len;
+
+			g_string_append_len (user_data->def, name, len);
 			g_string_append (user_data->def, ": ");
 			expr = cr_term_to_string (a_expr);
 			g_string_append_len (user_data->def, expr, strlen (expr));
