@@ -128,8 +128,8 @@ rsvg_start_svg (RsvgHandle *ctx, const xmlChar **atts)
 					if (new_width < 0 || new_height < 0)
 						{
 							g_warning ("rsvg_start_svg: width and height not specified in the SVG");
-							if (new_width < 0) new_width = 500;
-							if (new_height < 0) new_height = 500;
+							if (new_width < 0) {width = new_width = 512;}
+							if (new_height < 0) {height = new_height = 512;}
 						}
 
 					/* apply the sizing function to acquire our new width and height.
@@ -174,8 +174,8 @@ rsvg_start_svg (RsvgHandle *ctx, const xmlChar **atts)
 			if (new_width < 0 || new_height < 0)
 				{
 					g_warning ("rsvg_start_svg: width and height not specified in the SVG, nor supplied by the size callback");
-					if (new_width < 0) new_width = 500;
-					if (new_height < 0) new_height = 500;
+					if (new_width < 0) new_width = 512;
+					if (new_height < 0) new_height = 512;
 				}
 
 			if (new_width >= INT_MAX / 4)
